@@ -4,7 +4,7 @@ use std::path::Path;
 use crate::config::Replace;
 use crate::error::CargoResult;
 
-pub static NOW: once_cell::sync::Lazy<String> = once_cell::sync::Lazy::new(|| {
+pub static NOW: std::sync::LazyLock<String> = std::sync::LazyLock::new(|| {
     time::OffsetDateTime::now_utc()
         .format(time::macros::format_description!("[year]-[month]-[day]"))
         .unwrap()
@@ -53,7 +53,7 @@ fn render_var(mut template: String, var_name: &str, var_value: Option<&str>) ->
     if let Some(var_value) = var_value {
         template = template.replace(var_name, var_value);
     } else if template.contains(var_name) {
-        log::warn!("Unrendered {} present in template {:?}", var_name, template);
+        log::warn!("Unrendered {var_name} present in template {template:?}");
     }
     template
 }
