@@ -169,7 +169,7 @@ impl PackageRelease {
                     git::find_last_tag(&package_root, &tag_glob)
                 }
                 Err(err) => {
-                    log::debug!("failed to find tag with glob `{}`: {}", tag_glob, err);
+                    log::debug!("failed to find tag with glob `{tag_glob}`: {err}");
                     None
                 }
             }
@@ -317,10 +317,10 @@ fn find_dependents<'w>(
     pkg_meta: &'w cargo_metadata::Package,
 ) -> impl Iterator<Item = (&'w cargo_metadata::Package, &'w cargo_metadata::Dependency)> {
     ws_meta.packages.iter().filter_map(move |p| {
-        if ws_meta.workspace_members.iter().any(|m| *m == p.id) {
+        if ws_meta.workspace_members.contains(&p.id) {
             p.dependencies
                 .iter()
-                .find(|d| d.name == pkg_meta.name)
+                .find(|d| d.name == pkg_meta.name.as_str())
                 .map(|d| (p, d))
         } else {
             None
