@@ -80,7 +80,7 @@ impl PushStep {
             pkg.config.release = Some(false);
 
             let crate_name = pkg.meta.name.as_str();
-            log::debug!("disabled by user, skipping {}", crate_name,);
+            log::debug!("disabled by user, skipping {crate_name}",);
         }
 
         let pkgs = plan::plan(pkgs)?;
