@@ -82,22 +82,22 @@ impl TagStep {
             pkg.config.release = Some(false);
 
             let crate_name = pkg.meta.name.as_str();
-            log::debug!("disabled by user, skipping {}", crate_name,);
+            log::debug!("disabled by user, skipping {crate_name}",);
         }
 
         let mut pkgs = plan::plan(pkgs)?;
 
         for pkg in pkgs.values_mut() {
-            if let Some(tag_name) = pkg.planned_tag.as_ref() {
-                if git::tag_exists(ws_meta.workspace_root.as_std_path(), tag_name)? {
-                    let crate_name = pkg.meta.name.as_str();
-                    let _ = crate::ops::shell::warn(format!(
-                        "disabled due to existing tag ({tag_name}), skipping {crate_name}"
-                    ));
-                    pkg.planned_tag = None;
-                    pkg.config.tag = Some(false);
-                    pkg.config.release = Some(false);
-                }
+            if let Some(tag_name) = pkg.planned_tag.as_ref()
+                && git::tag_exists(ws_meta.workspace_root.as_std_path(), tag_name)?
+            {
+                let crate_name = pkg.meta.name.as_str();
+                let _ = crate::ops::shell::warn(format!(
+                    "disabled due to existing tag ({tag_name}), skipping {crate_name}"
+                ));
+                pkg.planned_tag = None;
+                pkg.config.tag = Some(false);
+                pkg.config.release = Some(false);
             }
         }
 
@@ -158,33 +158,33 @@ impl TagStep {
 pub fn tag(pkgs: &[plan::PackageRelease], dry_run: bool) -> Result<(), CliError> {
     let mut seen_tags = HashSet::new();
     for pkg in pkgs {
-        if let Some(tag_name) = pkg.planned_tag.as_ref() {
-            if seen_tags.insert(tag_name) {
-                let cwd = &pkg.package_root;
-                let crate_name = pkg.meta.name.as_str();
+        if let Some(tag_name) = pkg.planned_tag.as_ref()
+            && seen_tags.insert(tag_name)
+        {
+            let cwd = &pkg.package_root;
+            let crate_name = pkg.meta.name.as_str();
 
-                let version = pkg.planned_version.as_ref().unwrap_or(&pkg.initial_version);
-                let prev_version_var = pkg.initial_version.bare_version_string.as_str();
-                let prev_metadata_var = pkg.initial_version.full_version.build.as_str();
-                let version_var = version.bare_version_string.as_str();
-                let metadata_var = version.full_version.build.as_str();
-                let template = Template {
-                    prev_version: Some(prev_version_var),
-                    prev_metadata: Some(prev_metadata_var),
-                    version: Some(version_var),
-                    metadata: Some(metadata_var),
-                    crate_name: Some(crate_name),
-                    tag_name: Some(tag_name),
-                    date: Some(NOW.as_str()),
-                    ..Default::default()
-                };
-                let tag_message = template.render(pkg.config.tag_message());
+            let version = pkg.planned_version.as_ref().unwrap_or(&pkg.initial_version);
+            let prev_version_var = pkg.initial_version.bare_version_string.as_str();
+            let prev_metadata_var = pkg.initial_version.full_version.build.as_str();
+            let version_var = version.bare_version_string.as_str();
+            let metadata_var = version.full_version.build.as_str();
+            let template = Template {
+                prev_version: Some(prev_version_var),
+                prev_metadata: Some(prev_metadata_var),
+                version: Some(version_var),
+                metadata: Some(metadata_var),
+                crate_name: Some(crate_name),
+                tag_name: Some(tag_name),
+                date: Some(NOW.as_str()),
+                ..Default::default()
+            };
+            let tag_message = template.render(pkg.config.tag_message());
 
-                log::debug!("creating git tag {}", tag_name);
-                if !git::tag(cwd, tag_name, &tag_message, pkg.config.sign_tag(), dry_run)? {
-                    // tag failed, abort release
-                    return Err(101.into());
-                }
+            log::debug!("creating git tag {tag_name}");
+            if !git::tag(cwd, tag_name, &tag_message, pkg.config.sign_tag(), dry_run)? {
+                // tag failed, abort release
+                return Err(101.into());
             }
         }
     }
